@@ -1,6 +1,6 @@
 calcGamma <- function(Gamma0,Lsubk3,U,dims,weights=NULL)
   {
-      U <- as( U,"sparseMatrix")
+      U <- as(U,"sparseMatrix")
       ULU <- crossprod(U,(Lsubk3%*%U))
       ULU2 <-  crossprod(U,(Lsubk3%*%Gamma0))
       diag(ULU) <- diag(ULU)+1e-8
@@ -9,7 +9,7 @@ calcGamma <- function(Gamma0,Lsubk3,U,dims,weights=NULL)
       Gamma1 <- try(Gamma0 - weights*(U%*%solve(ULU,ULU2)))
       if (class(Gamma1)=="try-error") {
           cat("calcGamma: singular matrix: general inverse will be used.\n")
-          B <- ginv(as.matrix(ULU))		
+          B <- armaGinv(as.matrix(ULU))		
           Gamma1 <- Gamma0-weights*(U%*%B%*%crossprod(U,(Lsubk3%*%Gamma0)))
     }
       Gamatrix <- matrix(Gamma1,length(Gamma1)/dims,dims)
