@@ -24,6 +24,6 @@
 conv2backf <- function(mesh)
 { 	
 	mesh$it <- mesh$it[c(3,2,1),]
-        mesh <- updateNormals(mesh)
+        mesh <- vcgUpdateNormals(mesh)
   	return(mesh)
 }
