@@ -4,8 +4,8 @@
 #' deforming a cubic grid based on a thin-plate spline interpolation
 #' 
 #' 
-#' @param matrix reference matrix containing 3D landmark coordinates.
-#' @param tarmatrix target matrix containing 3D landmark coordinates.
+#' @param matrix reference matrix containing 3D landmark coordinates or mesh of class "mesh3d"
+#' @param tarmatrix target matrix containing 3D landmark coordinates or mesh of class "mesh3d"
 #' @param ngrid number of grid lines to be plotted; ngrid=0 suppresses grid
 #' creation.
 #' @param lwd width of lines connecting landmarks.
@@ -19,6 +19,7 @@
 #' @param col2 color of "tarmat"
 #' @param type "s" renders landmarks as spheres; "p" as points - much faster
 #' for very large pointclouds.
+#' @param size control size/radius of points/spheres
 #' @author Stefan Schlager
 #' @seealso \code{\link{tps3d}}
 #' 
@@ -28,10 +29,14 @@
 #' deformGrid3d(shortnose.lm,longnose.lm,ngrid=10)
 #' }
 #' @export
-deformGrid3d <- function(matrix,tarmatrix,ngrid=10,lwd=1,showaxis=c(1, 2), both=T,lines=TRUE,lcol=1,add=FALSE,col1=2,col2=3,type=c("s","p"))
+deformGrid3d <- function(matrix,tarmatrix,ngrid=0,lwd=1,showaxis=c(1, 2), both=T,lines=TRUE,lcol=1,add=FALSE,col1=2,col2=3,type=c("s","p"),size=NULL)
 {
+    if (inherits(matrix,"mesh3d"))
+        matrix <- vert2points(matrix)
+    if (inherits(tarmatrix,"mesh3d"))
+        tarmatrix <- vert2points(tarmatrix)
     type <- type[1]
-    if (dim(matrix)[1] > 1000 && type =="s") {
+    if (dim(matrix)[1] > 1000 && type =="s" && (is.null(size) || size > 0)) {
         answer <- readline("You have a lot of landmarks\n Render them as points (faster)? (yes/NO)\n")
         if (! substr(answer,1L,1L) %in% c("n","N"))
             type <- "p"
@@ -43,13 +48,19 @@ deformGrid3d <- function(matrix,tarmatrix,ngrid=10,lwd=1,showaxis=c(1, 2), both=
         open3d()
     
     k <- dim(matrix)[1]
-    if (type != "p")
-        sz <- (cSize(matrix)/sqrt(k))*(1/80)
-    else
-        sz <- 10
-    out3d(matrix,col=col1,radius=sz, size=sz)
+    if (is.null(size)) {
+        if (type != "p")
+            sz <- (cSize(matrix)/sqrt(k))*(1/80)
+        else
+            sz <- 10
+    } else {
+        sz <- size
+    }
+    if (is.numeric(size) && size > 0)
+        out3d(matrix,col=col1,radius=sz, size=sz)
     if(both) {
-        out3d(tarmatrix,col=col2,radius=sz, size=sz)
+        if (is.numeric(size) && size > 0)
+            out3d(tarmatrix,col=col2,radius=sz, size=sz)
         if (lines) {
             linemesh <- list()
             linemesh$vb <- t(cbind(rbind(matrix,tarmatrix),1))
