@@ -85,6 +85,7 @@ meshDist <- function(x,...) UseMethod("meshDist")
 
 #' @rdname meshDist
 #' @method meshDist mesh3d
+#' @importFrom Rvcg vcgClostKD
 #' @export
 meshDist.mesh3d <- function(x, mesh2=NULL, distvec=NULL, from=NULL, to=NULL, steps=20, ceiling=FALSE, file="default", imagedim="100x800", uprange=1, ray=FALSE, raytol=50, save=FALSE, plot=TRUE, sign=TRUE, tol=NULL, displace=FALSE, shade=TRUE, method=c("morpho", "vcglib"), add=FALSE, ...)
   {
@@ -94,7 +95,7 @@ meshDist.mesh3d <- function(x, mesh2=NULL, distvec=NULL, from=NULL, to=NULL, ste
     if (is.null(distvec)) {
         if(!ray) {
             if (method == "v") {
-                promesh <- projRead(t(x$vb[1:3,]),mesh2,readnormals=T,sign=T)
+                promesh <- vcgClostKD(x,mesh2,sign=T)
             } else {
                 promesh <- closemeshKD(x,mesh2,sign=T)
             }
@@ -163,6 +164,7 @@ meshDist.mesh3d <- function(x, mesh2=NULL, distvec=NULL, from=NULL, to=NULL, ste
     
     colfun <- function(x){x <- colorall[x];return(x)}
     x$material$color <- matrix(colfun(x$it),dim(x$it))
+    x$material$color[is.na(x$material$color)] <- "#FFFFFF"
     colramp <- list(1,colseq, matrix(data=colseq, ncol=length(colseq),nrow=1),col=ramp,useRaster=T,ylab="Distance in mm",xlab="",xaxt="n")
     params <- list(steps=steps,from=from,to=to,uprange=uprange,ceiling=ceiling,sign=sign,tol=tol)
     out <- list(colMesh=x,dists=distsOrig,cols=colorall,colramp=colramp,params=params,distqual=distqual,clost=clost)
